==> qxcommon-1.0.02-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDLoginReq.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDLoginReq extends QXBaseContent implements IHDloginType {

    /**
     * authId：认证id
     * 可以为：工号 邮箱 手机号 用户名等
     * authSecret:认证密钥
     * 可以为：手机/邮箱验证码 密码等
     * captcha:web 界面的验证码(选填参数)
     * type：登录方式
     * 1.工号密码登录
     * <p>
     * authId :  authId
     * authSecret : authSectet
     * captcha : captcha
     * type : 1
     */

    private String authId;
    private String authSecret;
    private String captcha;
    private int type;

    public HDLoginReq() {
    }

    public HDLoginReq(String authId, String authSecret, String captcha, int type) {
        this.authId = authId;
        this.authSecret = authSecret;
        this.captcha = captcha;
        this.type = type;
    }

    @Override
    public String toString() {
        return "HDLoginReq{" +
                "authId='" + authId + '\'' +
                ", authSecret='" + authSecret + '\'' +
                ", captcha='" + captcha + '\'' +
                ", type=" + type +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public String getAuthId() {
        return authId;
    }

    public void setAuthId(String authId) {
        this.authId = authId;
    }

    public String getAuthSecret() {
        return authSecret;
    }

    public void setAuthSecret(String authSecret) {
        this.authSecret = authSecret;
    }

    public String getCaptcha() {
        return captcha;
    }

    public void setCaptcha(String captcha) {
        this.captcha = captcha;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_LOGIN;
    }
}

==> qxcommon-1.0.24-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDLoginReq.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDLoginReq extends QXBaseContent implements IHDloginType {

    /**
     * authId：认证id
     * 可以为：工号 邮箱 手机号 用户名等
     * authSecret:认证密钥
     * 可以为：手机/邮箱验证码 密码等
     * captcha:web 界面的验证码(选填参数)
     * type：登录方式
     * 1.工号密码登录
     * <p>
     * authId :  authId
     * authSecret : authSectet
     * captcha : captcha
     * type : 1
     */

    protected String authId;
    protected String authSecret;
    protected String captcha;
    protected int type;

    public HDLoginReq() {
    }

    public HDLoginReq(String authId, String authSecret, String captcha, int type) {
        this.authId = authId;
        this.authSecret = authSecret;
        this.captcha = captcha;
        this.type = type;
    }

    @Override
    public String toString() {
        return "HDLoginReq{" +
                "authId='" + authId + '\'' +
                ", authSecret='" + authSecret + '\'' +
                ", captcha='" + captcha + '\'' +
                ", type=" + type +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public String getAuthId() {
        return authId;
    }

    public void setAuthId(String authId) {
        this.authId = authId;
    }

    public String getAuthSecret() {
        return authSecret;
    }

    public void setAuthSecret(String authSecret) {
        this.authSecret = authSecret;
    }

    public String getCaptcha() {
        return captcha;
    }

    public void setCaptcha(String captcha) {
        this.captcha = captcha;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_LOGIN;
    }
}
